@@ -5,6 +5,13 @@ from apscheduler.schedulers.background import BackgroundScheduler
 from pytz import utc
 from harp_gate_client.notifications_collectors.push_notification import notification_scraper
 import harp_gate_client.settings as settings
+import threading
+from harp_gate_client.logic.config_update import update_configuration
+
+
+def schedule_watchdog():
+    watchdog_service = threading.Thread(name='Configuration Watchdog', target=update_configuration, daemon=True)
+    watchdog_service.start()
 
 
 def schedule_jobs():
@@ -26,6 +33,7 @@ def main():
 
 
 if __name__ == '__main__':
+    schedule_watchdog()
     schedule_jobs()
     main()
 
